@@ -30,36 +30,31 @@
 
 #include "kgpgkey.h"
 #include "ui_adduid.h"
-#include "kgpginterface.h"
 #include "kgpgitemmodel.h"
 #include "kgpgitemnode.h"
 
 class QEvent;
 
 class KSelectAction;
-class KPassivePopup;
 class KStatusBar;
 class KMenu;
 class KLineEdit;
 class KAction;
+class KJob;
 
-class KgpgInterface;
 class KeyServer;
 class KgpgEditor;
 class KeyServer;
 class KeyListProxyModel;
 class KeyTreeView;
-class KGpgDelUid;
-class KGpgAddPhoto;
 class KGpgAddUid;
-class KGpgGenerateKey;
 class KGpgDelKey;
 class KGpgImport;
 class KGpgTextInterface;
+class KGpgTransactionJob;
+
+class KStatusNotifierItem;
 
-namespace Experimental {
-	class KNotificationItem;
-}
 
 class AddUid : public QWidget, public Ui::AddUid
 {
@@ -126,17 +121,16 @@ public slots:
     void clipEncrypt();
     void clipDecrypt();
     void clipSign();
-    
+    void slotImportDone(int ret);
+    void refreshKeys(const QStringList &ids);
+
 protected:
     bool eventFilter(QObject *, QEvent *e);
     void removeFromGroups(KGpgKeyNode *nd);
+    void setDefaultKeyNode(KGpgKeyNode *key);
 
 private slots:
-    void statusBarTimeout();
-    void changeMessage(const QString &msg, const int nb, const bool keep = false);
-
-    void slotGenerateKeyProcess();
-    void slotGenerateKeyDone(int res);
+    void slotGenerateKeyDone(KJob *job);
 
     void slotShowTrust();
     void slotShowSize();
@@ -153,6 +147,7 @@ private slots:
     void slotDelUid();
     void slotDelUidDone(int);
     void slotPrimUid();
+    void slotPrimUidDone(int result);
     void slotAddUid();
     void slotAddUidEnable(const QString &name);
     void slotUpdatePhoto();
@@ -161,27 +156,29 @@ private slots:
     void slotAddPhotoFinished(int res);
     void slotSetPhotoSize(int size);
     void slotShowPhoto();
-    void slotrevoke(const QString &keyID, const KUrl &revokeUrl, const int reason, const QString &description);
     void revokeWidget();
-    void doFilePrint(const KUrl &url);
+    void slotRevokeDialogFinished(int result);
+    void slotRevokeGenerated(int result);
     void doPrint(const QString &txt);
     void checkList();
-    void signLoop();
     void slotManpage();
     void slotTip();
-    void slotProcessExportMail(const QString &keys);
-    void slotProcessExportClip(const QString &keys);
+    void slotExportFinished(int result);
+    void slotProcessExportMail(int result);
+    void slotProcessExportClip(int result);
     void readOptions();
     void slotSetDefKey();
     void confirmdeletekey();
     void deleteseckey();
     void signkey();
     void signuid();
+    void caff();
+    void slotCaffDone();
     void delsignkey();
     void preimportsignkey();
     void importallsignkey();
-    void signatureResult(int success, const QString &keyId, KgpgInterface*);
-    void delsignatureResult(bool);
+    void signatureResult(int success);
+    void delsignatureResult(int success);
     void defaultAction(const QModelIndex &);
     void defaultAction(KGpgNode *);
     void slotDefaultAction();
@@ -189,6 +186,7 @@ private slots:
     void keyproperties();
     void slotexport();
     void slotexportsec();
+    void slotExportSecFinished(int result);
 
     void slotMenu(const QPoint &);
 
@@ -198,7 +196,6 @@ private slots:
     void editGroup();
     void createNewGroup();
     void deleteGroup();
-    void slotImportRevoke(const KUrl &url);
     void slotImportRevokeTxt(const QString &revokeText);
     void refreshKeyFromServer();
     void slotKeyRefreshDone(int result);
@@ -207,11 +204,8 @@ private slots:
     void getMissingSigs(QSet<QString> &missingKeys, const KGpgExpandableNode *nd);
     void slotEditDone(int exitcode);
     void importRemoteFinished(int result);
-    void slotRefreshKeys(KgpgInterface *iface, const QStringList &keys);
     void slotDelKeyDone(int ret);
-    void slotImportDone(int ret);
-    void slotImportDone(KGpgImport *import, int ret);
-    void slotSetClip(const QString &newtxt, KGpgTextInterface *iface);
+    void slotSetClip(const QString &newtxt);
 
     void slotNetworkUp();
     void slotNetworkDown();
@@ -221,20 +215,17 @@ private:
     KeyListProxyModel *iproxy;
     KeyTreeView *iview;
 
-    KGpgDelUid *m_deluid;
-    KGpgAddPhoto *m_addphoto;
     KGpgAddUid *m_adduid;
-    KGpgGenerateKey *m_genkey;
+    KGpgTransactionJob *m_genkey;
     KGpgDelKey *m_delkey;
 
     QString globalkeyID;
     QString searchString;
 
-    QList<KGpgNode *> signList;
+    QList<KGpgSignableNode *> signList;
     QList<KGpgKeyNode *> refreshList;
 
     QClipboard::Mode m_clipboardmode;
-    QTimer *m_statusbartimer;
 
     KMenu *m_popuppub;          // popup on a public key
     KMenu *m_popupsec;          // popup on a secret key
@@ -245,9 +236,6 @@ private:
     KMenu *m_popupuid;          // popup on an user id
     KMenu *m_popuporphan;       // popup on an orphan key
 
-    KPassivePopup *pop;
-    KStatusBar *m_statusbar;
-
     KLineEdit *m_listviewsearch;
     KDialog *addUidWidget;
 
@@ -255,6 +243,7 @@ private:
     KAction *importAllSignKeys;
     KAction *signKey;
     KAction *signUid;
+    KAction *signMailUid;
     KAction *refreshKey;
     KAction *editKey;
     KAction *setPrimUid;
@@ -271,22 +260,18 @@ private:
     KAction *createGroup;
 
     KeyServer *kServer;
-    KgpgInterface *revKeyProcess;
 
     bool continueSearch;
-    bool globalisLocal;
     bool showTipOfDay;
-    bool m_isterminal;
     bool m_signuids;
 
     int keyCount;
-    int globalChecked;
 
     long searchOptions;
 
     KGpgKeyNode *terminalkey; // the key currently edited in a terminal
     KGpgKeyNode *delkey;	// key currently deleted
-    KGpgKeyNodeList m_delkeys;
+    KGpgKeyNode::List m_delkeys;
 
     void startImport(KGpgImport *import);
 
@@ -295,10 +280,34 @@ private:
     Solid::Networking::Notifier *m_netnote;
     void toggleNetworkActions(bool online);
 
-    Experimental::KNotificationItem *m_trayicon;
+    KStatusNotifierItem *m_trayicon;
     void setupTrayIcon();
 
     void setActionDescriptions(int cnt);
+    /**
+     * @brief show a message in the status bar
+     * @param msg the text to show
+     * @param keep if the text should stay visible or may be hidden after a while
+     */
+    void changeMessage(const QString &msg, const bool keep = false);
+    /**
+     * @brief update the key and group counter in the status bar
+     */
+    void updateStatusCounter();
+    /**
+     * @brief sign the next key from signList
+     * @param localsign if signature should be a local (not exportable) one
+     * @param checklevel how careful the identity of the key was checked
+     */
+    void signLoop(const bool localsign, const int checklevel);
+    /**
+     * @brief Opens the console when the user want to sign a key manually.
+     * @param signer key to sign with
+     * @param keyid key to sign
+     * @param checking how carefule the identify was checked
+     * @param local if signature should be local (not exportable)
+     */
+    void signKeyOpenConsole(const QString &signer, const QString &keyid, const int checking, const bool local);
 };
 
 #endif // KEYSMANAGER_H
