@@ -102,6 +102,13 @@ KeyListProxyModelPrivate::dataSingleColumn(const QModelIndex &index, int role, c
 				return i18nc("Name <Email>: ID", "%1 &lt;%2&gt;: %3", name, mail, id);
 		}
 		}
+	case Qt::ToolTipRole: {
+		const QModelIndex srcidx(q->mapToSource(index));
+		const int srcrow = srcidx.row();
+
+		const QModelIndex ididx(srcidx.sibling(srcrow, KEYCOLUMN_ID));
+		return m_model->data(ididx, Qt::DisplayRole);
+		}
 	default:
 		return QVariant();
 	}
@@ -322,7 +329,7 @@ KeyListProxyModel::filterAcceptsRow(int source_row, const QModelIndex &source_pa
 }
 
 void
-KeyListProxyModel::setOnlySecret(const bool &b)
+KeyListProxyModel::setOnlySecret(const bool b)
 {
 	Q_D(KeyListProxyModel);
 
@@ -331,7 +338,7 @@ KeyListProxyModel::setOnlySecret(const bool &b)
 }
 
 void
-KeyListProxyModel::setTrustFilter(const KgpgCore::KgpgKeyTrustFlag &t)
+KeyListProxyModel::setTrustFilter(const KgpgCore::KgpgKeyTrustFlag t)
 {
 	Q_D(KeyListProxyModel);
 
@@ -356,7 +363,7 @@ KeyListProxyModel::nodeIndex(KGpgNode *node)
 }
 
 void
-KeyListProxyModel::setPreviewSize(const int &pixel)
+KeyListProxyModel::setPreviewSize(const int pixel)
 {
 	Q_D(KeyListProxyModel);
 
@@ -405,7 +412,7 @@ KeyListProxyModel::idLength() const
 }
 
 void
-KeyListProxyModel::setIdLength(const int &length)
+KeyListProxyModel::setIdLength(const int length)
 {
 	Q_D(KeyListProxyModel);
 
