@@ -22,6 +22,7 @@
 
 #include <KShortcut>
 #include <KDialog>
+#include <KUrl>
 #include <KVBox>
 
 #include "kgpgkey.h"
@@ -32,7 +33,6 @@ class QTableView;
 class KLineEdit;
 class KHBox;
 
-class KgpgInterface;
 class SelectKeyProxyModel;
 class KGpgItemModel;
 
@@ -44,7 +44,7 @@ public:
     /* TODO: the goDefaultKey shortcut should be stored in a way it can be accessed from everywhere. So we don't have to pass it as an argument.
      */
 
-    KgpgSelectPublicKeyDlg(QWidget *parent, KGpgItemModel *model, const KShortcut &goDefaultKey = KShortcut(QKeySequence(Qt::CTRL + Qt::Key_Home)), const QString &sfile = QString(), const bool &hideasciioption = false);
+    KgpgSelectPublicKeyDlg(QWidget *parent, KGpgItemModel *model, const KShortcut &goDefaultKey = KShortcut(QKeySequence(Qt::CTRL + Qt::Key_Home)), const bool hideasciioption = false, const KUrl::List &files = KUrl::List());
 
     QStringList selectedKeys() const;
     QString getCustomOptions() const;
