@@ -1,7 +1,7 @@
 /*
     This file is part of the Okteta Gui library, part of the KDE project.
 
-    Copyright 2003,2007,2008 Friedrich W. H. Kossebau <kossebau@kde.org>
+    Copyright 2003,2007-2009 Friedrich W. H. Kossebau <kossebau@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -27,11 +27,11 @@
 #include "bytearraytablecursor.h"
 #include "bytearraytablelayout.h"
 #include "helper.h"
-// ColumnsView
-#include <columnsview.h>
+// lib
+#include <abstractcolumnstylist.h>
 // Okteta core
-#include <kbookmarkable.h>
-#include <kbookmarksconstiterator.h>
+#include <bookmarkable.h>
+#include <bookmarksconstiterator.h>
 #include <bookmark.h>
 #include <charcodec.h>
 // KDE
@@ -40,25 +40,25 @@
 #include <QtGui/QPainter>
 
 
-namespace KHEUI
+namespace Okteta
 {
 
 static const unsigned int StartsBefore = 1;
 static const unsigned int EndsLater = 2;
-static const char EmptyByte = ' ';
+static const Byte EmptyByte = ' ';
 
-static const KPixelX DefaultCursorWidth = 2;
-static const KPixelX DefaultByteSpacingWidth = 3;
-static const KPixelX DefaultGroupSpacingWidth = 9;
+static const PixelX DefaultCursorWidth = 2;
+static const PixelX DefaultByteSpacingWidth = 3;
+static const PixelX DefaultGroupSpacingWidth = 9;
 static const int DefaultNoOfGroupedBytes = 4;
 
-AbstractByteArrayColumnRenderer::AbstractByteArrayColumnRenderer( ColumnsView *columnsView,
-    KHECore::AbstractByteArrayModel* byteArrayModel, ByteArrayTableLayout* layout, ByteArrayTableRanges* ranges )
- : ColumnRenderer( columnsView ),
+AbstractByteArrayColumnRenderer::AbstractByteArrayColumnRenderer( AbstractColumnStylist* stylist,
+    AbstractByteArrayModel* byteArrayModel, ByteArrayTableLayout* layout, ByteArrayTableRanges* ranges )
+ : AbstractColumnRenderer( stylist ),
    mByteArrayModel( byteArrayModel ),
    mLayout( layout ),
    mRanges( ranges ),
-   mBookmarks( qobject_cast<KHECore::Bookmarkable*>(byteArrayModel) ),
+   mBookmarks( qobject_cast<Bookmarkable*>(byteArrayModel) ),
    mDigitWidth( 0 ),
    mDigitBaseLine( 0 ),
    mByteWidth( 0 ),
@@ -73,10 +73,10 @@ AbstractByteArrayColumnRenderer::AbstractByteArrayColumnRenderer( ColumnsView *c
 }
 
 
-void AbstractByteArrayColumnRenderer::set( KHECore::AbstractByteArrayModel *byteArrayModel )
+void AbstractByteArrayColumnRenderer::set( AbstractByteArrayModel* byteArrayModel )
 {
     mByteArrayModel = byteArrayModel;
-    mBookmarks = qobject_cast<KHECore::Bookmarkable*>(byteArrayModel );
+    mBookmarks = qobject_cast<Bookmarkable*>(byteArrayModel );
 }
 
 
@@ -86,22 +86,22 @@ void AbstractByteArrayColumnRenderer::resetXBuffer()
     delete [] mLinePosRightPixelX;
 
     mLastLinePos = mLayout->noOfBytesPerLine()-1;
-    mLinePosLeftPixelX =  new KPixelX[mLastLinePos+1];
-    mLinePosRightPixelX = new KPixelX[mLastLinePos+1];
+    mLinePosLeftPixelX =  new PixelX[mLastLinePos+1];
+    mLinePosRightPixelX = new PixelX[mLastLinePos+1];
 
     if( mLinePosLeftPixelX )
         recalcX();
 }
 
 
-void AbstractByteArrayColumnRenderer::setMetrics( KPixelX digitWidth, KPixelY DBL )
+void AbstractByteArrayColumnRenderer::setMetrics( PixelX digitWidth, PixelY DBL )
 {
     mDigitBaseLine = DBL;
     setDigitWidth( digitWidth );
 }
 
 
-bool AbstractByteArrayColumnRenderer::setDigitWidth( KPixelX digitWidth )
+bool AbstractByteArrayColumnRenderer::setDigitWidth( PixelX digitWidth )
 {
     // no changes?
     if( mDigitWidth == digitWidth )
@@ -117,7 +117,7 @@ bool AbstractByteArrayColumnRenderer::setDigitWidth( KPixelX digitWidth )
 }
 
 
-bool AbstractByteArrayColumnRenderer::setSpacing( KPixelX byteSpacingWidth, int NoGB, KPixelX groupSpacingWidth )
+bool AbstractByteArrayColumnRenderer::setSpacing( PixelX byteSpacingWidth, int NoGB, PixelX groupSpacingWidth )
 {
     // no changes?
     if( mByteSpacingWidth == byteSpacingWidth && mNoOfGroupedBytes == NoGB && mGroupSpacingWidth == groupSpacingWidth )
@@ -135,7 +135,7 @@ bool AbstractByteArrayColumnRenderer::setSpacing( KPixelX byteSpacingWidth, int
 }
 
 
-bool AbstractByteArrayColumnRenderer::setByteSpacingWidth( KPixelX byteSpacingWidth )
+bool AbstractByteArrayColumnRenderer::setByteSpacingWidth( PixelX byteSpacingWidth )
 {
     // no changes?
     if( mByteSpacingWidth == byteSpacingWidth )
@@ -165,7 +165,7 @@ bool AbstractByteArrayColumnRenderer::setNoOfGroupedBytes( int NoGB )
 }
 
 
-bool AbstractByteArrayColumnRenderer::setGroupSpacingWidth( KPixelX groupSpacingWidth )
+bool AbstractByteArrayColumnRenderer::setGroupSpacingWidth( PixelX groupSpacingWidth )
 {
     // no changes?
     if( mGroupSpacingWidth == groupSpacingWidth )
@@ -191,11 +191,11 @@ void AbstractByteArrayColumnRenderer::recalcX()
 {
     mSpacingTrigger = noOfGroupedBytes() > 0 ? noOfGroupedBytes()-1 : mLastLinePos+1; // last ensures to never trigger the spacing
 
-    KPixelX newWidth = 0;
-    int groupedBytes = 0;
-    KPixelX *PX = mLinePosLeftPixelX;
-    KPixelX *PRX = mLinePosRightPixelX;
-    int p = 0;
+    PixelX newWidth = 0;
+    Size groupedBytes = 0;
+    PixelX* PX = mLinePosLeftPixelX;
+    PixelX* PRX = mLinePosRightPixelX;
+    LinePosition p = 0;
     for( ; p<=mLastLinePos; ++PX, ++PRX, ++p, ++groupedBytes )
     {
         *PX = newWidth;
@@ -209,7 +209,7 @@ void AbstractByteArrayColumnRenderer::recalcX()
             groupedBytes = -1;
         }
         else
-        newWidth += mByteSpacingWidth;
+            newWidth += mByteSpacingWidth;
     }
     setWidth( mLinePosRightPixelX[mLastLinePos]+1 );
 }
@@ -217,7 +217,7 @@ void AbstractByteArrayColumnRenderer::recalcX()
 
 // TODO: why are inlined functions not available as symbols when defined before their use
 //TODO: works not precisly for the byte rects but includes spacing and left and right
-/*inline*/ int AbstractByteArrayColumnRenderer::linePositionOfX( KPixelX PX ) const
+/*inline*/ LinePosition AbstractByteArrayColumnRenderer::linePositionOfX( PixelX PX ) const
 {
     if( !mLinePosLeftPixelX )
         return NoByteFound;
@@ -225,7 +225,7 @@ void AbstractByteArrayColumnRenderer::recalcX()
     // translate
     PX -= x();
     // search backwards for the first byte that is equalleft to x
-    for( int p=mLastLinePos; p>=0; --p )
+    for( LinePosition p=mLastLinePos; p>=0; --p )
         if( mLinePosLeftPixelX[p] <= PX )
             return p;
 
@@ -233,7 +233,7 @@ void AbstractByteArrayColumnRenderer::recalcX()
 }
 
 
-int AbstractByteArrayColumnRenderer::magneticLinePositionOfX( KPixelX PX ) const
+LinePosition AbstractByteArrayColumnRenderer::magneticLinePositionOfX( PixelX PX ) const
 {
     if( !mLinePosLeftPixelX )
         return NoByteFound;
@@ -241,7 +241,7 @@ int AbstractByteArrayColumnRenderer::magneticLinePositionOfX( KPixelX PX ) const
     // translate
     PX -= x();
     // search backwards for the first byte that is equalleft to x
-    for( int p=mLastLinePos; p>=0; --p )
+    for( LinePosition p = mLastLinePos; p>=0; --p )
         if( mLinePosLeftPixelX[p] <= PX )
         {
             // are we close to the right?
@@ -254,18 +254,18 @@ int AbstractByteArrayColumnRenderer::magneticLinePositionOfX( KPixelX PX ) const
 }
 
 
-KHE::Section AbstractByteArrayColumnRenderer::linePositionsOfX( KPixelX PX, KPixelX PW ) const
+LinePositionRange AbstractByteArrayColumnRenderer::linePositionsOfX( PixelX PX, PixelX PW ) const
 {
     if( !mLinePosLeftPixelX )
-        return KHE::Section();
+        return LinePositionRange();
 
     // translate
     PX -= x();
-    const int PRX = PX + PW - 1;
+    const PixelX PRX = PX + PW - 1;
 
-    KHE::Section positions;
+    LinePositionRange positions;
     // search backwards for the first byte that is equalleft to x
-    for( int p=mLastLinePos; p>=0; --p )
+    for( LinePosition p=mLastLinePos; p>=0; --p )
         if( mLinePosLeftPixelX[p] <= PRX )
         {
             positions.setEnd( p );
@@ -282,20 +282,24 @@ KHE::Section AbstractByteArrayColumnRenderer::linePositionsOfX( KPixelX PX, KPix
 }
 
 
-KPixelX AbstractByteArrayColumnRenderer::xOfLinePosition( int linePosition ) const
-{ return x() + (mLinePosLeftPixelX?mLinePosLeftPixelX[linePosition]:0); }
+PixelX AbstractByteArrayColumnRenderer::xOfLinePosition( LinePosition linePosition ) const
+{
+    return x() + ( mLinePosLeftPixelX ? mLinePosLeftPixelX[linePosition] : 0 );
+}
 
-KPixelX AbstractByteArrayColumnRenderer::rightXOfLinePosition( int linePosition ) const
-{ return x() + (mLinePosRightPixelX?mLinePosRightPixelX[linePosition]:0); }
+PixelX AbstractByteArrayColumnRenderer::rightXOfLinePosition( LinePosition linePosition ) const
+{
+    return x() + ( mLinePosRightPixelX ? mLinePosRightPixelX[linePosition] : 0 );
+}
 
 
-int AbstractByteArrayColumnRenderer::linePositionOfColumnX( KPixelX PX ) const
+LinePosition AbstractByteArrayColumnRenderer::linePositionOfColumnX( PixelX PX ) const
 {
     if( !mLinePosLeftPixelX )
         return NoByteFound;
 
     // search backwards for the first byte that is equalleft to x
-    for( int p=mLastLinePos; p>=0; --p )
+    for( LinePosition p=mLastLinePos; p>=0; --p )
         if( mLinePosLeftPixelX[p] <= PX )
             return p;
 
@@ -303,21 +307,22 @@ int AbstractByteArrayColumnRenderer::linePositionOfColumnX( KPixelX PX ) const
 }
 
 
-KHE::Section AbstractByteArrayColumnRenderer::linePositionsOfColumnXs( KPixelX PX, KPixelX PW ) const
+LinePositionRange AbstractByteArrayColumnRenderer::linePositionsOfColumnXs( PixelX pixelX, PixelX pixelWidth ) const
 {
-    if( !mLinePosLeftPixelX )
-        return KHE::Section();
+    if( ! mLinePosLeftPixelX )
+        return LinePositionRange();
 
-    const int PRX = PX + PW - 1;
+    const PixelX rightPixelX = pixelX + pixelWidth - 1;
 
-    KHE::Section positions;
+    LinePositionRange positions;
     // search backwards for the first byte that is equalleft to x
-    for( int p=mLastLinePos; p>=0; --p )
-        if( mLinePosLeftPixelX[p] <= PRX )
+    for( LinePosition p=mLastLinePos; p>=0; --p )
+        if( mLinePosLeftPixelX[p] <= rightPixelX )
         {
+            const LinePosition endPos = p;
             positions.setEnd( p );
-            for( ; p>=0; --p )
-                if( mLinePosLeftPixelX[p] <= PX )
+            for( p=0; p<=endPos; ++p )
+                if( mLinePosRightPixelX[p] >= pixelX )
                 {
                     positions.setStart( p );
                     break;
@@ -329,35 +334,54 @@ KHE::Section AbstractByteArrayColumnRenderer::linePositionsOfColumnXs( KPixelX P
 }
 
 
-KPixelX AbstractByteArrayColumnRenderer::columnXOfLinePosition( int linePosition ) const
-{ return mLinePosLeftPixelX ? mLinePosLeftPixelX[linePosition] : 0; }
-KPixelX AbstractByteArrayColumnRenderer::columnRightXOfLinePosition( int linePosition ) const
-{ return mLinePosRightPixelX ? mLinePosRightPixelX[linePosition] : 0; }
-
-
-KPixelXs AbstractByteArrayColumnRenderer::xsOfLinePositionsInclSpaces( const KHE::Section &linePositions ) const
+PixelX AbstractByteArrayColumnRenderer::columnXOfLinePosition( LinePosition linePosition ) const
 {
-    const int x = (linePositions.start()>0) ? rightXOfLinePosition( linePositions.nextBeforeStart() ) + 1 :
-                                              xOfLinePosition( linePositions.start() );
-    const int rightX = (linePositions.end()<mLastLinePos) ? xOfLinePosition( linePositions.nextBehindEnd() ) - 1 :
-                                                            rightXOfLinePosition( linePositions.end() );
-    return KPixelXs( x, rightX );
+    return mLinePosLeftPixelX ? mLinePosLeftPixelX[linePosition] : 0;
+}
+
+PixelX AbstractByteArrayColumnRenderer::columnRightXOfLinePosition( LinePosition linePosition ) const
+{
+    return mLinePosRightPixelX ? mLinePosRightPixelX[linePosition] : 0;
 }
 
 
-KPixelXs AbstractByteArrayColumnRenderer::columnXsOfLinePositionsInclSpaces( const KHE::Section &linePositions ) const
+PixelXRange AbstractByteArrayColumnRenderer::xsOfLinePositionsInclSpaces( const LinePositionRange& linePositions ) const
 {
-    const int x = (linePositions.start()>0) ? columnRightXOfLinePosition( linePositions.nextBeforeStart() ) + 1 :
-                                              columnXOfLinePosition( linePositions.start() );
-    const int rightX = (linePositions.end()<mLastLinePos) ? columnXOfLinePosition( linePositions.nextBehindEnd() ) - 1 :
-                                                            columnRightXOfLinePosition( linePositions.end() );
-    return KPixelXs( x, rightX  );
+    const PixelX x = (linePositions.start()>0) ? rightXOfLinePosition( linePositions.nextBeforeStart() ) + 1 :
+                                                 xOfLinePosition( linePositions.start() );
+    const PixelX rightX = (linePositions.end()<mLastLinePos) ? xOfLinePosition( linePositions.nextBehindEnd() ) - 1 :
+                                                               rightXOfLinePosition( linePositions.end() );
+    return PixelXRange( x, rightX );
 }
 
 
-void AbstractByteArrayColumnRenderer::prepareRendering( const KPixelXs &_Xs )
+PixelXRange AbstractByteArrayColumnRenderer::columnXsOfLinePositionsInclSpaces( const LinePositionRange& linePositions ) const
 {
-    KPixelXs Xs( _Xs );
+    const PixelX x = (linePositions.start()>0) ? columnRightXOfLinePosition( linePositions.nextBeforeStart() ) + 1 :
+                                                 columnXOfLinePosition( linePositions.start() );
+    const PixelX rightX = (linePositions.end()<mLastLinePos) ? columnXOfLinePosition( linePositions.nextBehindEnd() ) - 1 :
+                                                               columnRightXOfLinePosition( linePositions.end() );
+    return PixelXRange( x, rightX  );
+}
+
+
+QRect AbstractByteArrayColumnRenderer::byteRect( const Coord& coord ) const
+{
+    const int x = xOfLinePosition( coord.pos() );
+    const int y = lineHeight() * coord.line();
+    const int w = mByteWidth;
+    const int h = lineHeight();
+    const QPoint point( x, y );
+    const QSize size( w, h );
+
+    const QRect result( point, size );
+    return result;
+}
+
+
+void AbstractByteArrayColumnRenderer::prepareRendering( const PixelXRange& _Xs )
+{
+    PixelXRange Xs( _Xs );
     restrictToXSpan( &Xs );
     // translate
     Xs.moveBy( -x() );
@@ -371,7 +395,7 @@ void AbstractByteArrayColumnRenderer::prepareRendering( const KPixelXs &_Xs )
 }
 
 
-void AbstractByteArrayColumnRenderer::renderFirstLine( QPainter *painter, const KPixelXs &Xs, int firstLineIndex )
+void AbstractByteArrayColumnRenderer::renderFirstLine( QPainter* painter, const PixelXRange& Xs, Line firstLineIndex )
 {
     prepareRendering( Xs );
 
@@ -381,39 +405,41 @@ void AbstractByteArrayColumnRenderer::renderFirstLine( QPainter *painter, const
 }
 
 
-void AbstractByteArrayColumnRenderer::renderNextLine( QPainter *painter )
+void AbstractByteArrayColumnRenderer::renderNextLine( QPainter* painter )
 {
     renderLinePositions( painter, mRenderLine++, mRenderLinePositions );
 }
 
 
-void AbstractByteArrayColumnRenderer::renderLinePositions( QPainter *painter, int lineIndex, const KHE::Section &_linePositions )
+void AbstractByteArrayColumnRenderer::renderLinePositions( QPainter* painter, Line lineIndex, const LinePositionRange& _linePositions )
 {
     // clear background
     const unsigned int blankFlag =
         (_linePositions.start()!=0?StartsBefore:0) | (_linePositions.end()!=mLastLinePos?EndsLater:0);
-    const QWidget *viewport = columnsView()->viewport();
-    const QBrush &backgroundBrush = viewport->palette().brush( viewport->backgroundRole() );
+    const QBrush& backgroundBrush = stylist()->palette().brush( QPalette::Base );
 
     renderRange( painter, backgroundBrush, _linePositions, blankFlag );
 
-    // Go through the lines TODO: handle first and last line more effeciently
-    // check for leading and trailing spaces
-    KHE::Section linePositions( mLayout->firstLinePosition(Coord( _linePositions.start(), lineIndex )),
-                                 mLayout->lastLinePosition( Coord( _linePositions.end(),   lineIndex )) );
-
     // no bytes to paint?
     if( !mLayout->hasContent(lineIndex) )
         return;
 
+    // Go through the lines TODO: handle first and last line more effeciently
     // check for leading and trailing spaces
-    KHE::Section byteIndizes =
-        KHE::Section::fromWidth( mLayout->indexAtCoord(Coord( linePositions.start(), lineIndex )), linePositions.width() );
+    const LinePositionRange existingLinePositions = mLayout->linePositions( lineIndex );
+
+    LinePositionRange linePositions = _linePositions;
+    linePositions.restrictTo( existingLinePositions );
+    const int firstLinePosition = linePositions.start();
+
+    // check for leading and trailing spaces
+    AddressRange byteIndizes =
+        AddressRange::fromWidth( mLayout->indexAtCoord(Coord( linePositions.start(), lineIndex )), linePositions.width() );
 
     unsigned int selectionFlag = 0;
     unsigned int markingFlag = 0;
-    KHE::Section selection;
-    KHE::Section markedSection;
+    AddressRange selectedRange;
+    AddressRange markedRange;
     bool hasMarking = mRanges->hasMarking();
     bool hasSelection = mRanges->hasSelection();
 
@@ -422,42 +448,46 @@ void AbstractByteArrayColumnRenderer::renderLinePositions( QPainter *painter, in
 //         <<" for byteIndizes "<<byteIndizes.start()<<"-"<<byteIndizes.start()<<endl;
     while( linePositions.isValid() )
     {
-        KHE::Section positionsPart( linePositions );  // set of linePositions to paint next
-        KHE::Section byteIndizesPart( byteIndizes );      // set of indizes to paint next
-        // falls markedSection nicht mehr gebuffert und noch zu erwarten
-        if( hasMarking && markedSection.endsBefore(byteIndizesPart.start()) )
-        {
-            // erhebe nächste Markierung im Bereich
-            hasMarking = isMarked( byteIndizesPart, &markedSection, &markingFlag );
-        }
-        // falls selection nicht mehr gebuffert und noch zu erwarten
-        if( hasSelection && selection.endsBefore(byteIndizesPart.start()) )
-        {
-            // erhebe nächste selection im Bereich
-            hasSelection = isSelected( byteIndizesPart, &selection, &selectionFlag );
-        }
+        LinePositionRange positionsPart = linePositions;  // set of linePositions to paint next
+        AddressRange byteIndizesPart = byteIndizes;      // set of indizes to paint next
 
-        if( markedSection.start() == byteIndizesPart.start() )
+        if( hasMarking && markedRange.endsBefore(byteIndizesPart) )
+            hasMarking = getNextMarkedAddressRange( &markedRange, &markingFlag, byteIndizesPart );
+
+        if( hasSelection && selectedRange.endsBefore(byteIndizesPart) )
+            hasSelection = getNextSelectedAddressRange( &selectedRange, &selectionFlag, byteIndizesPart );
+
+        if( byteIndizesPart.start() == markedRange.start() )
         {
-            byteIndizesPart.setEnd( markedSection.end() );
-            positionsPart.setEndByWidth( markedSection.width() );
-            if( positionsPart.end() == mLayout->lastLinePosition(lineIndex) )   markingFlag &= ~EndsLater;
-            if( positionsPart.start() == mLayout->firstLinePosition(lineIndex)) markingFlag &= ~StartsBefore;
+            byteIndizesPart.setEnd( markedRange.end() );
+            positionsPart.setEndByWidth( markedRange.width() );
+
+            if( positionsPart.start() == existingLinePositions.start() ) markingFlag &= ~StartsBefore;
+            // TODO: hack: needed because otherwise the spacing will be plain
+            else if( positionsPart.start() == firstLinePosition && selectedRange.includes(byteIndizesPart.start()) )
+                renderSelectionSpaceBehind( painter, firstLinePosition-1 );
+
+            if( positionsPart.end() == existingLinePositions.end() )     markingFlag &= ~EndsLater;
+            // TODO: hack: needed because otherwise the spacing will be plain
+            else if( positionsPart.end() == linePositions.end() && selectedRange.includes(byteIndizesPart.end()) )
+                renderSelectionSpaceBehind( painter, positionsPart.end() );
+
             renderMarking( painter, positionsPart, byteIndizesPart.start(), markingFlag );
         }
-        else if( selection.includes(byteIndizesPart.start()) )
+        else if( selectedRange.includes(byteIndizesPart.start()) )
         {
-            if( selection.startsBehind(byteIndizesPart.start()) )
+            if( selectedRange.startsBefore(byteIndizesPart) )
                 selectionFlag |= StartsBefore;
-            bool MarkingBeforeEnd = hasMarking && markedSection.start() <= selection.end();
 
-            byteIndizesPart.setEnd( MarkingBeforeEnd ? markedSection.nextBeforeStart() : selection.end() );
+            const bool hasMarkingBeforeSelectionEnd = ( hasMarking && markedRange.start() <= selectedRange.end() );
+
+            byteIndizesPart.setEnd( hasMarkingBeforeSelectionEnd ? markedRange.nextBeforeStart() : selectedRange.end() );
             positionsPart.setEndByWidth( byteIndizesPart.width() );
 
-            if( MarkingBeforeEnd )
+            if( hasMarkingBeforeSelectionEnd )
                 selectionFlag |= EndsLater;
-            if( positionsPart.end() == mLayout->lastLinePosition(lineIndex) )    selectionFlag &= ~EndsLater;
-            if( positionsPart.start() == mLayout->firstLinePosition(lineIndex) ) selectionFlag &= ~StartsBefore;
+            if( positionsPart.start() == existingLinePositions.start() ) selectionFlag &= ~StartsBefore;
+            if( positionsPart.end() == existingLinePositions.end() )     selectionFlag &= ~EndsLater;
 
             renderSelection( painter, positionsPart, byteIndizesPart.start(), selectionFlag );
         }
@@ -465,39 +495,41 @@ void AbstractByteArrayColumnRenderer::renderLinePositions( QPainter *painter, in
         {
             // calc end of plain text
             if( hasMarking )
-                byteIndizesPart.setEnd( markedSection.nextBeforeStart() );
+                byteIndizesPart.setEnd( markedRange.nextBeforeStart() );
             if( hasSelection )
-                byteIndizesPart.restrictEndTo( selection.nextBeforeStart() );
+                byteIndizesPart.restrictEndTo( selectedRange.nextBeforeStart() );
 
             positionsPart.setEndByWidth( byteIndizesPart.width() );
+
             renderPlain( painter, positionsPart, byteIndizesPart.start() );
         }
+
         byteIndizes.setStartNextBehind( byteIndizesPart );
         linePositions.setStartNextBehind( positionsPart );
     }
 }
 
 
-void AbstractByteArrayColumnRenderer::renderPlain( QPainter *painter, const KHE::Section &linePositions, int byteIndex )
+void AbstractByteArrayColumnRenderer::renderPlain( QPainter* painter, const LinePositionRange& linePositions, Address byteIndex )
 {
-    KHECore::BookmarksConstIterator bit;
-    int nextBookmarkOffset = -1;
+    BookmarksConstIterator bit;
+    Address nextBookmarkOffset = -1;
 
     const bool hasBookmarks = ( mBookmarks != 0 );
     if( hasBookmarks )
     {
         bit = mBookmarks->createBookmarksConstIterator();
-        if( bit.findNextFrom( byteIndex) )
+        if( bit.findNextFrom(byteIndex) )
             nextBookmarkOffset = bit.next().offset();
     }
 
-    const QPalette &palette = columnsView()->viewport()->palette();
+    const QPalette& palette = stylist()->palette();
     KColorScheme colorScheme( palette.currentColorGroup(), KColorScheme::View );
 
     // paint all the bytes affected
-    for( int linePosition=linePositions.start(); linePosition<=linePositions.end(); ++linePosition,++byteIndex )
+    for( LinePosition linePosition=linePositions.start(); linePosition<=linePositions.end(); ++linePosition,++byteIndex )
     {
-        const KPixelX x = columnXOfLinePosition( linePosition );
+        const PixelX x = columnXOfLinePosition( linePosition );
 
         // draw the byte
         painter->translate( x, 0 );
@@ -509,13 +541,13 @@ void AbstractByteArrayColumnRenderer::renderPlain( QPainter *painter, const KHE:
             nextBookmarkOffset = bit.hasNext() ? bit.next().offset() : -1;//TODO )&& ( bit->offset() <= LastIndex );
         }
 
-        const char byte = mByteArrayModel->datum( byteIndex );
-        const KHECore::KChar byteChar = mCharCodec->decode( byte );
+        const Byte byte = mByteArrayModel->byte( byteIndex );
+        const Character byteChar = mCharCodec->decode( byte );
 
         const KColorScheme::ForegroundRole foregroundRole =
             mByteTypeColored ? foregroundRoleForChar(byteChar): KColorScheme::NormalText;
         const QBrush brush = colorScheme.foreground( foregroundRole );
-        const QColor &charColor = brush.color();// palette.text().color();//colorForChar(byteChar)
+        const QColor& charColor = brush.color();// palette.text().color();//colorForChar(byteChar)
         renderByteText( painter, byte, byteChar, charColor );
 
         painter->translate( -x, 0 );
@@ -523,10 +555,10 @@ void AbstractByteArrayColumnRenderer::renderPlain( QPainter *painter, const KHE:
 }
 
 
-void AbstractByteArrayColumnRenderer::renderSelection( QPainter *painter, const KHE::Section &linePositions, int byteIndex, int flag )
+void AbstractByteArrayColumnRenderer::renderSelection( QPainter* painter, const LinePositionRange& linePositions, Address byteIndex, int flag )
 {
-    KHECore::BookmarksConstIterator bit;
-    int nextBookmarkOffset = -1;
+    BookmarksConstIterator bit;
+    Address nextBookmarkOffset = -1;
 
     const bool hasBookmarks = ( mBookmarks != 0 );
     if( hasBookmarks )
@@ -536,15 +568,15 @@ void AbstractByteArrayColumnRenderer::renderSelection( QPainter *painter, const
             nextBookmarkOffset = bit.next().offset();
     }
 
-    const QPalette &palette = columnsView()->viewport()->palette();
+    const QPalette& palette = stylist()->palette();
     KColorScheme colorScheme( palette.currentColorGroup(), KColorScheme::Selection );
 
     renderRange( painter, colorScheme.background(), linePositions, flag );
 
     // paint all the bytes affected
-    for( int linePosition=linePositions.start(); linePosition<=linePositions.end(); ++linePosition,++byteIndex )
+    for( LinePosition linePosition=linePositions.start(); linePosition<=linePositions.end(); ++linePosition,++byteIndex )
     {
-        const KPixelX x = columnXOfLinePosition( linePosition );
+        const PixelX x = columnXOfLinePosition( linePosition );
 
         // draw the byte
         painter->translate( x, 0 );
@@ -556,36 +588,44 @@ void AbstractByteArrayColumnRenderer::renderSelection( QPainter *painter, const
             nextBookmarkOffset = bit.hasNext() ? bit.next().offset() : -1;//TODO )&& ( bit->offset() <= LastIndex );
         }
 
-        const char byte = mByteArrayModel->datum( byteIndex );
-        const KHECore::KChar byteChar = mCharCodec->decode( byte );
+        const Byte byte = mByteArrayModel->byte( byteIndex );
+        const Character byteChar = mCharCodec->decode( byte );
 
         const KColorScheme::ForegroundRole foregroundRole =
             mByteTypeColored ? foregroundRoleForChar(byteChar): KColorScheme::NormalText;
         const QBrush brush = colorScheme.foreground( foregroundRole );
-        const QColor &charColor = brush.color();
+        const QColor& charColor = brush.color();
         renderByteText( painter, byte, byteChar, charColor );
 
         painter->translate( -x, 0 );
     }
 }
 
-
-void AbstractByteArrayColumnRenderer::renderMarking( QPainter *painter, const KHE::Section &linePositions, int byteIndex, int flag )
+void AbstractByteArrayColumnRenderer::renderSelectionSpaceBehind( QPainter* painter, LinePosition linePosition )
 {
-    const QPalette &palette = columnsView()->viewport()->palette();
+    const QPalette& palette = stylist()->palette();
+    KColorScheme colorScheme( palette.currentColorGroup(), KColorScheme::Selection );
+
+    renderSpaceBehind( painter, colorScheme.background(), linePosition );
+}
+
+
+void AbstractByteArrayColumnRenderer::renderMarking( QPainter* painter, const LinePositionRange& linePositions, Address byteIndex, int flag )
+{
+    const QPalette& palette = stylist()->palette();
 
     renderRange( painter, palette.text(), linePositions, flag );
 
-    const QColor &baseColor = palette.base().color();
+    const QColor& baseColor = palette.base().color();
     // paint all the bytes affected
-    for( int p=linePositions.start(); p<=linePositions.end(); ++p,++byteIndex )
+    for( LinePosition p=linePositions.start(); p<=linePositions.end(); ++p,++byteIndex )
     {
-        const KPixelX x = columnXOfLinePosition( p );
+        const PixelX x = columnXOfLinePosition( p );
 
         // draw the byte
         painter->translate( x, 0 );
-        const char byte = mByteArrayModel->datum( byteIndex );
-        const KHECore::KChar byteChar = mCharCodec->decode( byte );
+        const Byte byte = mByteArrayModel->byte( byteIndex );
+        const Character byteChar = mCharCodec->decode( byte );
         renderByteText( painter, byte, byteChar, baseColor );
 
         painter->translate( -x, 0 );
@@ -593,19 +633,19 @@ void AbstractByteArrayColumnRenderer::renderMarking( QPainter *painter, const KH
 }
 
 
-void AbstractByteArrayColumnRenderer::renderBookmark( QPainter *painter, const QBrush &brush )
+void AbstractByteArrayColumnRenderer::renderBookmark( QPainter* painter, const QBrush& brush )
 {
     // TODO: think about how bookmarks should really be rendered
     painter->fillRect( 1,1, mByteWidth-2,lineHeight()-2, brush );
 }
 
 
-void AbstractByteArrayColumnRenderer::renderRange( QPainter *painter, const QBrush &brush, const KHE::Section &linePositions, int flag )
+void AbstractByteArrayColumnRenderer::renderRange( QPainter* painter, const QBrush& brush, const LinePositionRange& linePositions, int flag )
 {
-    const KPixelX rangeX =
+    const PixelX rangeX =
         ( flag & StartsBefore ) ? columnRightXOfLinePosition( linePositions.nextBeforeStart() ) + 1 :
                                   columnXOfLinePosition( linePositions.start() );
-    const KPixelX rangeW =
+    const PixelX rangeW =
         ( (flag & EndsLater) ? columnXOfLinePosition( linePositions.nextBehindEnd() ) :
                                columnRightXOfLinePosition( linePositions.end() ) + 1  )
         - rangeX;
@@ -613,14 +653,21 @@ void AbstractByteArrayColumnRenderer::renderRange( QPainter *painter, const QBru
     painter->fillRect( rangeX,0, rangeW,lineHeight(), brush );
 }
 
-
-void AbstractByteArrayColumnRenderer::renderByte( QPainter *painter, int byteIndex )
+void AbstractByteArrayColumnRenderer::renderSpaceBehind( QPainter* painter, const QBrush& brush, LinePosition linePosition )
 {
-    const char byte = ( byteIndex > -1 ) ? mByteArrayModel->datum( byteIndex ) : EmptyByte;
-    const KHECore::KChar byteChar = mCharCodec->decode( byte );
+    const PixelX rangeX = columnRightXOfLinePosition( linePosition ) + 1;
+    const PixelX rangeW = columnXOfLinePosition( linePosition+1 ) - rangeX;
 
-    const QWidget *viewport = columnsView()->viewport();
-    const QPalette &palette = viewport->palette();
+    painter->fillRect( rangeX,0, rangeW,lineHeight(), brush );
+}
+
+
+void AbstractByteArrayColumnRenderer::renderByte( QPainter* painter, Address byteIndex )
+{
+    const Byte byte = ( byteIndex > -1 ) ? mByteArrayModel->byte( byteIndex ) : EmptyByte;
+    const Character byteChar = mCharCodec->decode( byte );
+
+    const QPalette& palette = stylist()->palette();
 
     KColorScheme::ColorSet colorSet = KColorScheme::View;
     if( byteIndex > -1 )
@@ -646,29 +693,29 @@ void AbstractByteArrayColumnRenderer::renderByte( QPainter *painter, int byteInd
         const KColorScheme::ForegroundRole foregroundRole =
             mByteTypeColored ? foregroundRoleForChar(byteChar): KColorScheme::NormalText;
         const QBrush brush = colorScheme.foreground( foregroundRole );
-        const QColor &charColor = brush.color();
+        const QColor& charColor = brush.color();
 
         renderByteText( painter, byte, byteChar, charColor );
     }
 }
 
 // TODO: think about making framestyle a enum of a class ByteArrayColumnCursor
-void AbstractByteArrayColumnRenderer::renderFramedByte( QPainter *painter, int byteIndex, FrameStyle frameStyle )
+void AbstractByteArrayColumnRenderer::renderFramedByte( QPainter* painter, Address byteIndex, FrameStyle frameStyle )
 {
     renderByte( painter, byteIndex );
 
-    const char byte = ( byteIndex > -1 ) ? mByteArrayModel->datum( byteIndex ) : EmptyByte;
-    const KHECore::KChar byteChar = mCharCodec->decode( byte );
+    const Byte byte = ( byteIndex > -1 ) ? mByteArrayModel->byte( byteIndex ) : EmptyByte;
+    const Character byteChar = mCharCodec->decode( byte );
 
     const bool isInSelection = ( byteIndex > -1 && mRanges->selectionIncludes(byteIndex) );
     const KColorScheme::ColorSet colorSet = isInSelection ? KColorScheme::Selection : KColorScheme::View;
 
-    const QPalette &palette = columnsView()->viewport()->palette();
+    const QPalette& palette = stylist()->palette();
     KColorScheme colorScheme( palette.currentColorGroup(), colorSet );
     const KColorScheme::ForegroundRole foregroundRole =
         mByteTypeColored ? foregroundRoleForChar(byteChar): KColorScheme::NormalText;
     const QBrush brush = colorScheme.foreground( foregroundRole );
-    const QColor &charColor = brush.color();
+    const QColor& charColor = brush.color();
     painter->setPen( charColor );
     if( frameStyle == Frame )
         painter->drawRect( 0,0, mByteWidth-1,lineHeight()-1 );
@@ -679,15 +726,15 @@ void AbstractByteArrayColumnRenderer::renderFramedByte( QPainter *painter, int b
 }
 
 
-void AbstractByteArrayColumnRenderer::renderCursor( QPainter *painter, int byteIndex )
+void AbstractByteArrayColumnRenderer::renderCursor( QPainter* painter, Address byteIndex )
 {
-    const char byte = ( byteIndex > -1 ) ? mByteArrayModel->datum( byteIndex ) : EmptyByte;
-    const KHECore::KChar byteChar = mCharCodec->decode( byte );
+    const Byte byte = ( byteIndex > -1 ) ? mByteArrayModel->byte( byteIndex ) : EmptyByte;
+    const Character byteChar = mCharCodec->decode( byte );
 
     const bool isInSelection = ( byteIndex > -1 && mRanges->selectionIncludes(byteIndex) );
     const KColorScheme::ColorSet colorSet = isInSelection ? KColorScheme::Selection : KColorScheme::View;
 
-    const QPalette &palette = columnsView()->viewport()->palette();
+    const QPalette& palette = stylist()->palette();
     KColorScheme colorScheme( palette.currentColorGroup(), colorSet );
     const KColorScheme::ForegroundRole foregroundRole =
         mByteTypeColored ? foregroundRoleForChar(byteChar): KColorScheme::NormalText;
@@ -696,59 +743,59 @@ void AbstractByteArrayColumnRenderer::renderCursor( QPainter *painter, int byteI
 }
 
 
-bool AbstractByteArrayColumnRenderer::isSelected( const KHE::Section &section, KHE::Section *_selection,
-                                                  unsigned int *_flag ) const
+bool AbstractByteArrayColumnRenderer::getNextSelectedAddressRange( AddressRange* _selection, unsigned int* _flag,
+                                                                   const AddressRange& range ) const
 {
-    const KHE::Section *overlappingSelectedSection = mRanges->firstOverlappingSelection( section );
+    const AddressRange* overlappingSelectedSection = mRanges->firstOverlappingSelection( range );
     if( !overlappingSelectedSection )
         return false;
 
-    KHE::Section selection = *overlappingSelectedSection;
+    AddressRange selectedRange = *overlappingSelectedSection;
     unsigned int flag = 0;
 
-    // does selection start before asked range?
-    if( selection.startsBefore(section) )
+    // does selectedRange start before asked range?
+    if( selectedRange.startsBefore(range) )
     {
-        selection.setStart( section.start() );
+        selectedRange.setStart( range.start() );
         flag |= StartsBefore;
     }
 
-    // does selection go on behind asked range?
-    if( selection.endsBehind(section) )
+    // does selectedRange go on behind asked range?
+    if( selectedRange.endsBehind(range) )
     {
-        selection.setEnd( section.end() );
+        selectedRange.setEnd( range.end() );
         flag |= EndsLater;
     }
 
-    *_selection = selection;
+    *_selection = selectedRange;
     *_flag = flag;
     return true;
 }
 
 
-bool AbstractByteArrayColumnRenderer::isMarked( const KHE::Section &section, KHE::Section *_markedSection,
-                                                unsigned int *_flag ) const
+bool AbstractByteArrayColumnRenderer::getNextMarkedAddressRange( AddressRange* _markedSection, unsigned int* _flag,
+                                                                 const AddressRange& range ) const
 {
-    const KHE::Section *overlappingMarkedSection = mRanges->overlappingMarking( section );
+    const AddressRange* overlappingMarkedSection = mRanges->overlappingMarking( range );
     if( !overlappingMarkedSection )
         return false;
 
     unsigned int flag = 0;
-    KHE::Section markedSection = *overlappingMarkedSection;
+    AddressRange markedRange = *overlappingMarkedSection;
 
-    if( markedSection.startsBefore(section) )
+    if( markedRange.startsBefore(range) )
     {
-        markedSection.setStart( section.start() );
+        markedRange.setStart( range.start() );
         flag |= StartsBefore;
     }
 
-    if( markedSection.endsBehind(section) )
+    if( markedRange.endsBehind(range) )
     {
-        markedSection.setEnd( section.end() );
+        markedRange.setEnd( range.end() );
         flag |= EndsLater;
     }
 
-    *_markedSection = markedSection;
+    *_markedSection = markedRange;
     *_flag = flag;
     return true;
 }
